@@ -7,7 +7,7 @@ use yozuk_sdk::prelude::*;
 #[test]
 fn build_info() {
     assert_eq!(
-        cmd(tk!(["build", "info"])),
-        CommandArgs::new().add_args(["yozuk-skill-version", "--build-info"])
+        cmd(tk!(["version", "info"])),
+        CommandArgs::new().add_args(["yozuk-skill-version", "--version-info"])
     );
 }
